@@ -64,7 +64,6 @@ typedef enum {
 	R_DBG_PROC_RAISED = 'R' // has produced a signal, breakpoint, etc..
 } RDebugPidState;
 
-
 // signal handling must support application and debugger level options
 typedef enum {
 	R_DBG_SIGNAL_IGNORE = 0, // ignore signal handler
@@ -73,7 +72,6 @@ typedef enum {
 	//..
 } RDebugSignalMode;
 
-
 /*
  * when a user wants to resume from a breakpoint, we need to know how they want
  * to proceed. these values indicate their intention.
@@ -91,7 +89,6 @@ typedef enum {
 	R_DEBUG_REASON_DEAD = -1,
 	R_DEBUG_REASON_NONE = 0,
 	R_DEBUG_REASON_SIGNAL,
-	R_DEBUG_REASON_SEGFAULT,
 	R_DEBUG_REASON_BREAKPOINT,
 	R_DEBUG_REASON_TRACEPOINT,
 	R_DEBUG_REASON_COND,
@@ -113,10 +110,12 @@ typedef enum {
 	R_DEBUG_REASON_SWI,
 	R_DEBUG_REASON_INT,
 	R_DEBUG_REASON_FPU,
-	R_DEBUG_REASON_USERSUSP,
+	R_DEBUG_REASON_USERSUSP, // ?
+	R_DEBUG_REASON_SEGFAULT,
+	R_DEBUG_REASON_STOPPED,
+	R_DEBUG_REASON_TERMINATED,
 } RDebugReasonType;
 
-
 /* TODO: move to r_anal */
 typedef struct r_debug_frame_t {
 	ut64 addr;
@@ -427,9 +426,9 @@ typedef struct r_debug_pid_t {
  */
 #ifdef R_API
 R_API RDebug *r_debug_new(int hard);
-R_API RDebug *r_debug_free(RDebug *dbg);
+R_API void r_debug_free(RDebug *dbg);
 
-R_API int r_debug_attach(RDebug *dbg, int pid);
+R_API bool r_debug_attach(RDebug *dbg, int pid);
 R_API int r_debug_detach(RDebug *dbg, int pid);
 R_API int r_debug_startv(RDebug *dbg, int argc, char **argv);
 R_API int r_debug_start(RDebug *dbg, const char *cmd);
@@ -508,7 +507,7 @@ R_API void r_debug_map_list(RDebug *dbg, ut64 addr, const char *input);
 R_API void r_debug_map_list_visual(RDebug *dbg, ut64 addr, const char *input, int colors);
 
 /* descriptors */
-R_API RDebugDesc *r_debug_desc_new (int fd, char* path, int perm, int type, int off);
+R_API RDebugDesc *r_debug_desc_new (int fd, const char *path, int perm, int type, int off);
 R_API void r_debug_desc_free (RDebugDesc *p);
 R_API int r_debug_desc_open(RDebug *dbg, const char *path);
 R_API int r_debug_desc_close(RDebug *dbg, int fd);
